@@ -275,7 +275,7 @@ class ActorManager(messaging.MessageManager):
         self.ipc_transport.connect(server_addr)
         self._should_quit = _should_quit
         self.groups[self.PYSAGE_MAIN_GROUP] = (None,server_addr,None)
-    def listen(self, host, port, transport_class=transport.SelectUDPTransport):
+    def listen(self, transport_class=transport.SelectUDPTransport, **kws):
         '''
         starts listening for network messages given the port and the transport class
 
@@ -287,9 +287,9 @@ class ActorManager(messaging.MessageManager):
         def connection_handler(client_address):
             self.log(logging.DEBUG, 'connected to client: %s' % client_address)
         self.transport = transport_class()
-        self.transport.listen(host, port, connection_handler)
+        self.transport.listen(connection_handler=connection_handler, **kws)
         return self
-    def connect(self, host, port, transport_class=transport.SelectUDPTransport):
+    def connect(self, transport_class=transport.SelectUDPTransport, **kws):
         '''
         connects to a server so that message communication can be started
 
@@ -298,7 +298,7 @@ class ActorManager(messaging.MessageManager):
             - `port`: the port for which to connect to
         '''
         self.transport = transport_class()
-        self.transport.connect(host, port)
+        self.transport.connect(**kws)
         return self
     def disconnect(self):
         self.transport.disconnect()
